.. trikit documentation master file, created by
   sphinx-quickstart on Mon Sep  3 10:45:51 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

===============================================================================
``trikit`` --- Actuarial Reserving Tools and Techniques
===============================================================================



.. toctree::
   :maxdepth: 1
   :titlesonly:
   
   Project Overview <overview>
   Quickstart Guide <quickstart>
   Triangle Implementation <triangle>
   The Chain Ladder Method <chainladder>
   Reserve Variability Estimates <range>
   Sample Datasets <datasets>
   The CAS Loss Reserving Database <lrdb>
   Frequently Asked Questions <questions>
   